@@ -14,12 +14,15 @@ use MooX::TypeTiny;
 use Types::Common::Numeric qw/ PositiveOrZeroInt PositiveInt /;
 use Types::Standard qw/ is_Int Int ArrayRef is_HashRef /;
 
+
+use asa 'Data::Page';
+
 use namespace::autoclean;
 
 # RECOMMEND PREREQ: Type::Tiny::XS
 # RECOMMEND PREREQ: Ref::Util::XS
 
-our $VERSION = 'v0.3.0';
+our $VERSION = 'v0.3.1';
 
 
 has total_entries => (
@@ -312,15 +315,6 @@ sub BUILDARGS {
 }
 
 
-sub isa {
-    my ($self, $class) = @_;
-
-    state $classes = { map { $_ => 1 } qw/ Data::Page / };
-
-    return $classes->{$class} || $self->UNIVERSAL::isa($class);
-}
-
-
 1;
 
 __END__
@@ -335,7 +329,7 @@ Data::Pageset::Exponential - Page numbering for very large page numbers
 
 =head1 VERSION
 
-version v0.3.0
+version v0.3.1
 
 =head1 SYNOPSIS
 
@@ -462,6 +456,8 @@ exponent.
 
 It is added for compatability with L<Data::Pageset>.
 
+=for Pod::Coverage isa
+
 =for Pod::Coverage series
 
 =for Pod::Coverage splice
@@ -472,8 +468,6 @@ It is added for compatability with L<Data::Pageset>.
 
 =for Pod::Coverage BUILDARGS
 
-=for Pod::Coverage isa
-
 =head1 KNOWN ISSUES
 
 =head2 Differences with Data::Page
